Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTon Roosendaal <ton@blender.org>2004-12-03 23:41:53 +0300
committerTon Roosendaal <ton@blender.org>2004-12-03 23:41:53 +0300
commitded466b0c27cb7a04ffd1363211026981d91c8f4 (patch)
tree0e3154f8b70ac6506518598d790bc6695b8d1e95 /source/blender/src/editobject.c
parent73b7d9f80b4b6e40778c7dfdca3801738ba3be59 (diff)
Bug fix #1945
Undo push missing after "ALT/SHIFT+D and ESC".
Diffstat (limited to 'source/blender/src/editobject.c')
-rw-r--r--source/blender/src/editobject.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/src/editobject.c b/source/blender/src/editobject.c
index a5430267a21..cef0bae07d5 100644
--- a/source/blender/src/editobject.c
+++ b/source/blender/src/editobject.c
@@ -6681,8 +6681,8 @@ void transform(int mode)
set_constline_callback(0, 0, 0, NULL, NULL, NULL, NULL, NULL); // disable
/* undo after transform, since it's storing current situations */
- /* extrude has no own undo-push, so on cancel we still insert it */
- if(canceled==0 || strcmp(undostr, "Extrude")==0)
+ /* extrude/duplicate has no own undo-push, so on cancel we still insert it */
+ if(canceled==0 || strcmp(undostr, "Extrude")==0 || strcmp(undostr, "Duplicate")==0)
BIF_undo_push(undostr);
}